diff --git a/OpenSim/Framework/Servers/HttpServer/OSHttpServer/HttpRequest.cs b/OpenSim/Framework/Servers/HttpServer/OSHttpServer/HttpRequest.cs
index cfd60debeb..a0bdaeceec 100644
--- a/OpenSim/Framework/Servers/HttpServer/OSHttpServer/HttpRequest.cs
+++ b/OpenSim/Framework/Servers/HttpServer/OSHttpServer/HttpRequest.cs
@@ -14,7 +14,7 @@ namespace OSHttpServer
///
public class HttpRequest : IHttpRequest
{
- private const int MAXCONTENTLENGHT = 250 * 1024 * 1024;
+ private const int MAXCONTENTLENGTH = 250 * 1024 * 1024;
///
/// Chars used to split an URL path into multiple parts.
///
@@ -341,7 +341,7 @@ namespace OSHttpServer
case "content-length":
if (!int.TryParse(value, out int t))
throw new BadRequestException("Invalid content length.");
- if (t > MAXCONTENTLENGHT)
+ if (t > MAXCONTENTLENGTH)
throw new OSHttpServer.Exceptions.HttpException(HttpStatusCode.RequestEntityTooLarge,"Request Entity Too Large");
ContentLength = t;
break;
diff --git a/OpenSim/Framework/Util.cs b/OpenSim/Framework/Util.cs
index 4a5fe44d15..607e0277fa 100644
--- a/OpenSim/Framework/Util.cs
+++ b/OpenSim/Framework/Util.cs
@@ -2723,10 +2723,10 @@ namespace OpenSim.Framework
}
}
- public static unsafe int osUTF8Getbytes(char* srcarray, int srclenght, byte* dstarray, int maxdstlen, bool NullTerm = true)
+ public static unsafe int osUTF8Getbytes(char* srcarray, int srclength, byte* dstarray, int maxdstlen, bool NullTerm = true)
{
int dstlen = NullTerm ? maxdstlen - 1 : maxdstlen;
- int srclen = srclenght >= dstlen ? dstlen : srclenght;
+ int srclen = srclength >= dstlen ? dstlen : srclength;
char c;
char* src = srcarray;
diff --git a/OpenSim/Region/ClientStack/Linden/UDP/LLClientView.cs b/OpenSim/Region/ClientStack/Linden/UDP/LLClientView.cs
index 80f26014b2..cbb26e7c20 100755
--- a/OpenSim/Region/ClientStack/Linden/UDP/LLClientView.cs
+++ b/OpenSim/Region/ClientStack/Linden/UDP/LLClientView.cs
@@ -1650,7 +1650,7 @@ namespace OpenSim.Region.ClientStack.LindenUDP
//finish this packet
bitpack.PackBitsFromByte(END_OF_PATCHES);
- // fix the datablock lenght
+ // fix the datablock length
datasize = bitpack.BytePos - 9;
data[8] = (byte)datasize;
data[9] = (byte)(datasize >> 8);
diff --git a/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs b/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
index 1f70b2cfda..de49cf1785 100644
--- a/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
+++ b/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
@@ -1212,9 +1212,9 @@ namespace OpenSim.Region.ScriptEngine.Shared.ScriptBase
m_OSSL_Functions.osSetInertiaAsSphere(mass, radius, centerOfMass);
}
- public void osSetInertiaAsCylinder(LSL_Float mass, LSL_Float radius, LSL_Float lenght, vector centerOfMass,rotation lslrot)
+ public void osSetInertiaAsCylinder(LSL_Float mass, LSL_Float radius, LSL_Float length, vector centerOfMass,rotation lslrot)
{
- m_OSSL_Functions.osSetInertiaAsCylinder( mass, radius, lenght, centerOfMass, lslrot);
+ m_OSSL_Functions.osSetInertiaAsCylinder( mass, radius, length, centerOfMass, lslrot);
}
public void osClearInertia()
diff --git a/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs b/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
index 8f0dfe4c94..f71b0dd4b3 100644
--- a/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
+++ b/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
@@ -4847,13 +4847,13 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
///
/// total mass of linkset
/// radius of the cylinder
/// lenght of the cylinder
/// location of center of mass relative to root prim in local coords
/// rotation of the cylinder, and so inertia, relative to local axis
///
/// cylinder axis aligned with Z axis. For other orientations provide the rotation.
///
- public void osSetInertiaAsCylinder(LSL_Float mass, LSL_Float radius, LSL_Float lenght, LSL_Vector centerOfMass, LSL_Rotation lslrot)
+ public void osSetInertiaAsCylinder(LSL_Float mass, LSL_Float radius, LSL_Float length, LSL_Vector centerOfMass, LSL_Rotation lslrot)
{
CheckThreatLevel();
@@ -4872,7 +4872,7 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
float r = (float)radius;
r *= r;
Inertia.Z = 0.5f * m * r;
- float t = (float)lenght;
+ float t = (float)length;
t *= t;
t += 3.0f * r;
t *= 8.333333e-2f * m;
@@ -4847,13 +4847,13 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
/// total mass of linkset
/// radius of the cylinder
- /// lenght of the cylinder
+ /// length of the cylinder
/// location of center of mass relative to root prim in local coords
/// rotation of the cylinder, and so inertia, relative to local axis